.BaseNode_nodeWrapper__3JBAX{position:relative;width:100%;min-height:20px}.BaseNode_handlesWrapper__uZCOZ{display:flex;width:100%}.BaseNode_handlesColumn__hhmz1{width:50%;position:relative;display:flex;flex-direction:column;overflow:hidden}.BaseNode_inputHandlesColumn__KO_EA{align-items:flex-start}.BaseNode_outputHandlesColumn__zqvb4{align-items:flex-end}.BaseNode_handleRow__kzjai{display:flex;align-items:center;overflow:hidden;white-space:nowrap;margin-bottom:.25rem}.BaseNode_handleCell__JF2Z7{display:flex;justify-content:center;align-items:center}.BaseNode_inputHandleCell__6_GNp{margin-right:.5rem}.BaseNode_outputHandleCell__gQ9MG{margin-left:.5rem}.BaseNode_handleLabelCell__1n31B{display:flex;align-items:center}.BaseNode_inputHandlesColumn__KO_EA .BaseNode_handleLabelCell__1n31B{margin-left:.5rem}.BaseNode_outputHandlesColumn__zqvb4 .BaseNode_handleLabelCell__1n31B{margin-right:.5rem}.BaseNode_handleLabel___s1bK{font-size:1rem;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:100%;display:block;z-index:1000}.BaseNode_handle__jAkx8{width:.8rem!important;height:.8rem!important;background:#555!important;position:relative;z-index:1001!important;top:auto;right:auto;transform:none}.BaseNode_handle__jAkx8:hover{background-color:#777}.BaseNode_collapsedHandleInput__3TIfv{left:0!important}.BaseNode_collapsedHandleInput__3TIfv,.BaseNode_collapsedHandleOutput__bTX3j{position:absolute!important;top:50%!important;transform:translateY(-50%)!important}.BaseNode_collapsedHandleOutput__bTX3j{right:4px!important}.BaseNode_baseNodeWrapper__F5Y3I{position:relative;transition:all .3s cubic-bezier(.4,0,.2,1)}.BaseNode_RouterNode__37dRn{background-color:#e0f7fa}.DynamicNode_nodeWrapper__A605f{position:relative;width:100%;min-height:20px}.DynamicNode_handlesWrapper__GEcjQ{display:flex;width:100%}.DynamicNode_handlesColumn__OSHUA{width:50%;position:relative;display:flex;flex-direction:column;overflow:hidden}.DynamicNode_inputHandlesColumn__neEG5{align-items:flex-start}.DynamicNode_outputHandlesColumn__FBEzX{align-items:flex-end}.DynamicNode_handleRow__Nc8pJ{display:flex;align-items:center;overflow:hidden;white-space:nowrap;margin-bottom:.25rem}.DynamicNode_handleCell__cwITF{display:flex;justify-content:center;align-items:center}.DynamicNode_inputHandleCell__x6mVu{margin-right:.5rem}.DynamicNode_outputHandleCell__ocaA_{margin-left:.5rem}.DynamicNode_handleLabelCell__tW6CK{display:flex;align-items:center}.DynamicNode_inputHandlesColumn__neEG5 .DynamicNode_handleLabelCell__tW6CK{margin-left:.5rem}.DynamicNode_outputHandlesColumn__FBEzX .DynamicNode_handleLabelCell__tW6CK{margin-right:.5rem}.DynamicNode_handleLabel__B6_0i{font-size:1rem;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:100%;display:block;z-index:1000}.DynamicNode_handle__BaPP9{width:.8rem!important;height:.8rem!important;background:#555!important;position:relative;z-index:1001!important;top:auto;right:auto;transform:none}.DynamicNode_handle__BaPP9:hover{background-color:#777}.DynamicNode_collapsedHandleInput__mkRuI{position:absolute!important;top:50%!important;left:0!important;transform:translateY(-50%)!important}.DynamicNode_collapsedHandleOutput__0TKTX{position:absolute!important;top:50%!important;right:4px!important;transform:translateY(-50%)!important}.DynamicNode_dynamicNodeWrapper__omzgl{position:relative;transition:all .3s cubic-bezier(.4,0,.2,1)}.DynamicNode_RouterNode__hNn31{background-color:#e0f7fa}.InputNode_nodeWrapper__0oTjk{position:relative;width:100%;min-height:20px}.InputNode_handlesWrapper__2lfy5{display:flex;width:100%}.InputNode_handlesColumn__duAXq{width:100%;position:relative}.InputNode_handleLabelCell__muuXa{width:calc(100% - 40px);padding-left:.75rem}.InputNode_handleCell__godAy{width:20px;vertical-align:middle;text-align:center}.InputNode_handleWrapper__iczQT{display:flex;justify-content:center;align-items:center;height:100%}.InputNode_handleLabel__xRYQg{font-size:1rem;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:200px;display:inline-block;position:relative;z-index:1000}.InputNode_handle__NZeOM{width:.8rem!important;height:.8rem!important;background:#555!important;position:relative;z-index:1001!important;top:auto;right:auto;transform:none}.InputNode_handle__NZeOM:hover{background-color:#777}.InputNode_collapsedHandleOutput__9_gTt{position:absolute!important;top:50%!important;right:4px!important;transform:translateY(-50%)!important}.InputNode_inputNodeWrapper__VOs8b{position:relative}