"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[657],{90657:(t,e,n)=>{n.d(e,{m:()=>d});var r=n(25779),a=n(94403),i=n(40010),o=n(3394),u=n(42599),s=n(61452),l=n(22003),f=n(38661),c=n(94834);function d(t,e){return function(t,e,n){var r,d;let h;let D=(0,i.q)(),m=null!==(d=null!==(r=null==n?void 0:n.locale)&&void 0!==r?r:D.locale)&&void 0!==d?d:a.c,M=(0,s.z)(t,e);if(isNaN(M))throw RangeError("Invalid time value");let v=Object.assign({},n,{addSuffix:null==n?void 0:n.addSuffix,comparison:M}),[g,x]=(0,u.x)(null==n?void 0:n.in,...M>0?[e,t]:[t,e]),X=function(t,e,n){let r=(+(0,f.a)(t)-+(0,f.a)(e))/1e3;return(0,c.u)(void 0)(r)}(x,g),w=Math.round((X-((0,o.G)(x)-(0,o.G)(g))/1e3)/60);if(w<2){if(null==n?void 0:n.includeSeconds){if(X<5)return m.formatDistance("lessThanXSeconds",5,v);if(X<10)return m.formatDistance("lessThanXSeconds",10,v);if(X<20)return m.formatDistance("lessThanXSeconds",20,v);if(X<40)return m.formatDistance("halfAMinute",0,v);else if(X<60)return m.formatDistance("lessThanXMinutes",1,v);else return m.formatDistance("xMinutes",1,v)}return 0===w?m.formatDistance("lessThanXMinutes",1,v):m.formatDistance("xMinutes",w,v)}if(w<45)return m.formatDistance("xMinutes",w,v);if(w<90)return m.formatDistance("aboutXHours",1,v);if(w<l.F6){let t=Math.round(w/60);return m.formatDistance("aboutXHours",t,v)}if(w<2520)return m.formatDistance("xDays",1,v);if(w<l.Nw){let t=Math.round(w/l.F6);return m.formatDistance("xDays",t,v)}if(w<2*l.Nw)return h=Math.round(w/l.Nw),m.formatDistance("aboutXMonths",h,v);if((h=function(t,e,n){let[r,a,i]=(0,u.x)(void 0,t,t,e),o=(0,s.z)(a,i),l=Math.abs(function(t,e,n){let[r,a]=(0,u.x)(void 0,t,e);return 12*(r.getFullYear()-a.getFullYear())+(r.getMonth()-a.getMonth())}(a,i));if(l<1)return 0;1===a.getMonth()&&a.getDate()>27&&a.setDate(30),a.setMonth(a.getMonth()-o*l);let c=(0,s.z)(a,i)===-o;(function(t,e){let n=(0,f.a)(t,void 0);return+function(t,e){let n=(0,f.a)(t,null==e?void 0:e.in);return n.setHours(23,59,59,999),n}(n,void 0)==+function(t,e){let n=(0,f.a)(t,null==e?void 0:e.in),r=n.getMonth();return n.setFullYear(n.getFullYear(),r+1,0),n.setHours(23,59,59,999),n}(n,void 0)})(r)&&1===l&&1===(0,s.z)(r,i)&&(c=!1);let d=o*(l-+c);return 0===d?0:d}(x,g))<12){let t=Math.round(w/l.Nw);return m.formatDistance("xMonths",t,v)}{let t=h%12,e=Math.trunc(h/12);return t<3?m.formatDistance("aboutXYears",e,v):t<9?m.formatDistance("overXYears",e,v):m.formatDistance("almostXYears",e+1,v)}}(t,(0,r.w)(t,Date.now()),e)}}}]);